
(cc Upper-Level)



;;;Top Concepts and some subconcepts used in the IKF-LEX application (corresponding to
;;;a version 1.7 in the obsolete versioning):

;;;Objects:
(defconcept Object
  :annotations ((Enduring-P) (Heterogeneous-Unity-Carrier) (Non-Extensional-P)
                ;;;(Independent)
                (DOCUMENTATION "The main characteristic of objects is that all of them are 
independent essential wholes. This does not mean that the corresponding property (being an object) 
carries proper unity, since there is no common unity criterion for objects. Among objects, we distinguish 
between physical extensional bodies and ordinary objects. Bodies are considered to be extensional 
(+E), while ordinary objects are not (~E). This means that we assume that all ordinary objects can 
change some of their parts while keeping their identity."))
  :is-primitive Entity
  :implies (:at-least 1 PARTICIPANT-IN)
  :in-partition $Entity$
  :partitions $Object$)
(defconcept Oggetto :is Object)

(defconcept Physical-Object
  :is-primitive Object
  :in-partition $Object$)
(defconcept Oggetto-Fisico :is Physical-Object)
(defconcept Abstract-Object
  :is-primitive Object
  :in-partition $Object$)
(defconcept Oggetto-Astratto :is Abstract-Object)

(defconcept Body
  :annotations ((Independent) (Heterogeneous-Unity-Carrier) (Extensional-P))
  :is-primitive Physical-Object)
(defconcept Corpo :is Body)
(defconcept Ordinary-Object
  :annotations ((Independent) (Heterogeneous-Unity-Carrier) (Anti-Extensional-P))
  :is-primitive Physical-Object)

(defconcept Oggetto-ordinario :is Ordinary-Object)
(defconcept Unitary-Collection
  :annotations ((Independent) (Heterogeneous-Unity-Carrier) (Anti-Extensional-P) (Plural-P))
  :is-primitive Ordinary-Object)
(defconcept Collezione-unitaria :is Unitary-Collection)

(defconcept Geographic-Object
  :is-primitive Ordinary-Object)
(defconcept Oggetto-geografico :is Geographic-Object)
(defconcept Physical-Place
  :is-primitive Geographic-Object)
(defconcept Luogo-Fisico
  :is Physical-Place)
(defconcept Biological-Object
  :is-primitive Ordinary-Object)
(defconcept Oggetto-Biologico
  :is Biological-Object)
(defconcept Organism
  :is-primitive Biological-Object)
(defconcept Organismo :is Organism)
(defconcept Artifact
  :is-primitive Ordinary-Object)
(defconcept Artefatto :is Artifact)
(defconcept Device
  :is-primitive Artifact)
(defconcept Mezzo
  :is Device)
(defconcept Vehicle
  :is-primitive Artifact)
(defconcept Veicolo
  :is Vehicle)
(defconcept Construction
  :is-primitive Artifact)
(defconcept Costruzione
  :is Construction)

(defconcept Mental-Object
  :is-primitive Abstract-Object)
(defconcept Social-Object
  :is-primitive Abstract-Object)
(defconcept Oggetto-Sociale :is Social-Object)

(defconcept Country
  :annotations ((DOCUMENTATION "This needs dependency axioms with Physical-Place
and Geographic-Area."))
  :is-primitive Social-Object)
(defconcept Paese
  :is Country
  :partitions $Paesi$)
(defconcept Person
  :annotations ((DOCUMENTATION "A social object with rights and duties"))
  :is-primitive Social-Object)
(defconcept Persona
  :annotations ((DOCUMENTATION "Un oggetto sociale con diritti e doveri."))
  :is Person)
(defconcept Natural-Person
  :annotations ((DOCUMENTATION "A person ontologically dependent on an organism"))
  :is-primitive Person)
(defconcept Persona-Naturale
  :annotations ((DOCUMENTATION "Una persona ontologicamente dipendente da un organismo
e la cui nascita co-occorre con quella dell'organismo."))
  :is Natural-Person)
(defconcept Socially-Constructed-Person
  :annotations ((DOCUMENTATION "A person which is constructed by other previously 
existing person (socially constructed or born"))
  :is-primitive Person)
(defconcept Persona-costruita-socialmente :is Socially-Constructed-Person)
;;;???(defconcept Position
;;;   :is-primitive Socially-Constructed-Person)
;;;(defconcept Posizione :is Position)
(defconcept Legally-Constructed-Person
  :is-primitive Socially-Constructed-Person)
(defconcept Persona-Legalmente-Costruita :is Legally-Constructed-Person)
(defconcept Organization
  :is-primitive Legally-Constructed-Person)
(defconcept Organizzazione :is Organization)
(defconcept Group
   :is-primitive Social-Object)
(defconcept Gruppo :is Group)
(defconcept Enterprise
  :is-primitive Organization)

(defconcept Information
  :is-primitive Social-Object)
(defconcept Informazione :is Information)
(defconcept Statement
  :is-primitive Information)
(defconcept Enunciato :is Statement)
(defconcept Text
  :is-primitive Information)
(defconcept Expression
  :is-primitive Information)
(defconcept |Plan|
  :is-primitive Information
  :implies (:and (:some REPRESENTS Occurrence)
                 (:some INVOLVES Object)))
(defconcept Measurement-Unit
  :is-primitive Expression)
(defconcept Testo
  :is Text)
(defconcept Espressione
  :is Expression)
(defconcept Piano
  :annotations ((DOCUMENTATION "Un'informazione la cui struttura rappresenta, suggerisce,
anticipa, regolamenta, etc. quella di un tipo di occorrenza."))
  :is |Plan|)
(defconcept Unit-Di-Misura
  :is Measurement-Unit)

;;;Aggregate:
(defconcept Aggregate
  :annotations ((Enduring-P) (Anti-Unity-Carrier) (Extensional-P)
                ;;;(Independent)
                (DOCUMENTATION "The common trait of aggregates is that they are independent 
entities, and none of them is an essential whole. This means that the corresponding property 
carries anti-unity (~U). We consider two kinds of aggregates: Amounts of matter and Arbitrary 
collections. The latter can be also called groups, or perhaps sets; we prefer however to use 
set for abstract entities, and group does sometimes denote something with an intrinsic unity. 
Arbitrary collections are just mere sums of wholes which are not themselves essential wholes. 
Amounts of matter are extensional (+E), in the sense that they change their identity when they 
change some parts; mere pluralitiesarbitrary collections can be considered as pseudo-extensional, 
in the sense that they change their identity when a member is changed, while a change in the 
parts of a member may be allowed."))
  :is-primitive Entity
  :in-partition $Entity$)
(defconcept Aggregato :is Aggregate)
(defconcept Amount-of-matter
  :annotations ((Independent) (Anti-Unity-Carrier) (Extensional-P))
  :is-primitive Aggregate)
(defconcept Ammasso-di-materia :is Amount-of-matter)
(defconcept Arbitrary-collection
  :annotations ((Independent) (Anti-Unity-Carrier) (Plural-P) (Pseudo-Extensional-P)
                (DOCUMENTATION "Also for arbitrary groups."))
  :is-primitive Aggregate)
(defconcept Collezione-arbitraria :is Arbitrary-collection)

;;;Quality:
(defconcept Quality
 :annotations ((Enduring-P) (Specifically-Constantly-Dependent) 
               ;;; (Extensional-P) (Unity-Carrier) (Singular-P)
                (DOCUMENTATION "A point in a quality-space. Qualities and properties are 
often considered as synonymous, but they are not. Take a particular object, like a rose: 
depending on its nature (and our way of perceiving it) it will exibit some individual 
qualities, like a specific color, a size, a smell, etc. The way we classify these qualities 
may depend on our conceptualization of them, which strongly depends on our culture and 
perceptual capabilities. Properties like red, big, sweet are the result of classifying 
each of these qualities with respect to a specific conceptual space [in the sense of Gardenfors]: 
the rose is red because its color is located in a certain region in the colors conceptual space. 
When we say that 'red is a color' we are talking of a region in this space; when we say 
'I like the color of this rose' we are talking of an individual quality. We assume that 
individual qualities do not change in time, while their conceptual location in a conceptual 
space can vary in time. The main characteristics of qualities is therefore their being 
located in conceptual spaces, whose topological structure depends on the quality being 
considered.
Speaking of their meta-properties, qualities are dependent entities. We also assume that they 
have no proper parts, so that they are trivially extensional and are trivially wholes. Finally, 
we assume that qualities of objects are physically located where the objects are located, so that 
qualities of concrete objects are themselves concrete. 
An important remark is that we take spatial and temporal locations of objects as individual 
qualities, too. This means that geometric space and time are considered as conceptual spaces."))
  :is-primitive Entity
  :implies (:some INHERES-IN Entity)
  :in-partition $Entity$)
(defconcept Qualit :is Quality)

(defconcept Physical-Quality
  :is-primitive Quality)
(defconcept Temporal-Quality
  :is-primitive Quality)
(defconcept Abstract-Quality
  :is-primitive Quality)
(defconcept Color
  :is-primitive Physical-Quality)
(defconcept Colore :is Color)
(defconcept Shape
  :is-primitive Physical-Quality)
(defconcept Forma :is Shape)
(defconcept Interval
  :is-primitive Temporal-Quality)
(defconcept Intervallo
  :is Interval)
(defconcept Date
  :is-primitive Temporal-Quality)
(defconcept Data
  :is Date)
;; start 06-08-2002
;;;attualmente supportato con Loom::Number, fuori dal dominio!
;;;(defconcept |Number|
;;;  :is-primitive |Quantity|)
;;;(defconcept Numero
;;;  :is |Number|)
(defconcept Numero
  :is Number)
;; end 06-08-2002

(defconcept Volume
  :is-primitive Physical-Quality)
(defconcept Spatial-Location
  :is-primitive Physical-Quality)
(defconcept Localizzazione-Spaziale
  :is Spatial-Location)
(defconcept Geographic-Area
  :is-primitive Spatial-Location)
(defconcept Area-Geografica
  :is Geographic-Area)
(defconcept Temporal-Location
  :is-primitive Temporal-Quality)
(defconcept Abstract-Location
  :is-primitive Abstract-Quality)
(defconcept Localizzazione-Temporale
  :is Spatial-Location)


;;;Quality-Space:
(defconcept Quality-Space
  :annotations ((Enduring-P) (Always-Present-P))
  :is-primitive Entity)
(defconcept Spazio-di-qualit :is Quality-Space)
(defconcept Abstract-Quality-Space
  :is-primitive Quality-Space)
(defconcept Physical-Quality-Space
  :is-primitive Quality-Space)
(defconcept Temporal-Quality-Space
  :is-primitive Quality-Space)
(defconcept Color-Space
  :is-primitive Physical-Quality-Space)
(defconcept Spazio-dei-colori :is Color-Space)
(defconcept Shape-Space
  :is-primitive Physical-Quality-Space)
(defconcept Spazio-delle-forme :is Shape-Space)
(defconcept Volume-Space
  :is-primitive Physical-Quality-Space)
(defconcept Spazio-dei-volumi :is Volume-Space)
(defconcept Dimension
  :is-primitive Quality-Space)
(defconcept Dimensione
  :is Dimension)
(defconcept Geographic-Space
  :is-primitive Spatial-Region)
(defconcept Spazio-Geografico :is Geographic-Space)
(defconcept Spatial-Region
  :is-primitive Physical-Quality-Space)
(defconcept Temporal-Region
  :is-primitive Temporal-Quality-Space)
(defconcept Regione-Temporale :is Temporal-Region)
(defconcept Boolean
  :is-primitive Abstract-Quality-Space)
(defconcept Quale
  :is (:and Quality-Space
            (:some PART-OF Quality-Space)
            (:exactly 0 PART Quality-Space)))
(defconcept Quality-Value
  :is (:and Quale
            (:some PART-OF Quality-Space)))

(defconcept Temporal-Value
  :is-primitive Quality-Value)

(defconcept Spatial-Value
  :is-primitive Quality-Value)

(defconcept Abstract-Value
  :is-primitive Quality-Value)



;;;Occurrence:
(defconcept Occurrence
  :annotations ((Perduring-P) 
                ;;;(Dependent) (Extensional-P)
                (DOCUMENTATION "Occurrences are things that happen in time, i.e. temporal occurrences. 
They are assumed to be dependent on those objects that are their participants. Therefore, an object 
that participates to an Occurrence is not part of that Occurrence. The necessity to distinguish objects from 
Occurrences is just a result of our cognitive-linguistic bias, and we do not make any metaphysical 
commitment regarding the 'primacy' of the former on the latter. "))
  :is-primitive Entity
  :implies (:and (:some PARTICIPANT Object)
                 (:some HAS-QUALITY Temporal-Location)
                 (:all HAS-QUALITY Incoherent Spatial-Location)
                 (:all PART Occurrence))
  :in-partition $Entity$
  :partitions $Relationality$
  :partitions $Homeomericity$
  :partitions $Intentionality$)
(defconcept Occorrenza :is Occurrence)

(defconcept State
  :annotations ((Homeomeric-P))
                ;;;(Static))
  :is-primitive Occurrence
  :in-partition $Homeomericity$)
(defconcept Stato :is State)
(defconcept Process
  :annotations ((Weakly-Homeomeric-P))
                ;;;(Dynamic) (Durative) (|Open|))
  :is-primitive Occurrence
  :in-partition $Homeomericity$)
(defconcept Processo 
  :annotations ((DOCUMENTATION "Un'occorrenza che non ha confini temporali predeterminati."))
  :is Process)
(defconcept Achievement
  :annotations ((DOCUMENTATION "The final result of an accomplishment"))
          ;;;  :annotations ((Dynamic) (Punctual))
  :is-primitive Occurrence
  :in-partition $Homeomericity$)
(defconcept Conseguimento
  :annotations ((DOCUMENTATION "Il confine (risultato atteso) di un evento compiuto."))
  :is Achievement)
(defconcept Accomplishment
  :annotations ((DOCUMENTATION "An Occurrence that contains its result as a boundary. It does
include aborted, suspended, misperformed accomplishments, and does NOT include processes that
have a result that wasn't intended as their achievement. This disclaimer leads to the conclusion
that the accomplishment/process distinction is dependent on intentionality."))
  :annotations ((Non-Homeomeric-P))
                ;;;(Dynamic) (Durative) (|Closed|))
  :is-primitive Occurrence
  :in-partition $Homeomericity$)
(defconcept Evento-Compiuto
  :annotations ((DOCUMENTATION "Un'occorrenza che contiene il suo risultato atteso come confine
temporale finale."))
  :is Accomplishment)


;;;Occorrenze incrociate con cardinalit dei partecipanti:
(defconcept Non-Relational-Occurrence
  :is-primitive Occurrence
  :implies (:exactly 1 PARTICIPANT)
  :in-partition $Relationality$)
(defconcept Relational-Occurrence
  :is-primitive Occurrence
  :implies (:at-least 2 PARTICIPANT)
  :in-partition $Relationality$)

;;;Occorrenze incrociate con intenzionalit:
(defconcept |Action|
  :annotations ((DOCUMENTATION "An Occurrence that exemplifies the intentionality of an agent.
In dependency terms, it is generically constantly dependent on a mental object.")
                (DOCUMENTATION "Could it be aborted, incomplete, misleaded while remaining a 
(potential) accomlishment?
The point here is that having a result depends on a plan, then an action remains an action
under incomplete results. On the other hand, if we neutralize intentionality, a purely
topological post-hoc view is at odds with the notion of incomplete accomplishments."))
  :annotations ((Intentional))
            ;;;(Dynamic) (Durative) (|Closed|)
  :is-primitive Accomplishment
  :in-partition $Intentionality$) 
(defconcept Azione
  :annotations ((DOCUMENTATION "Un evento iniziato da un agente (intenzionale)."))
  :is |Action|)
(defconcept Activity
  :annotations ((Intentional))
         ;;;(Dynamic) (Durative) (|Closed|)
  :is-primitive |Action|)
(defconcept Attivit
  :annotations ((DOCUMENTATION "Un'azione complessa e almeno in parte pianificata."))
  :is Activity)
(defconcept Phenomenon
  :annotations ((DOCUMENTATION "An Occurrence that does not exemplify the intentionality 
of an agent. In dependency terms, it is specifically constantly dependent on an ordinary
object."))
  :annotations ((Non-Intentional))
                ;;;(Dynamic) (Durative) (|Closed|)
  :is-primitive Occurrence
  :in-partition $Intentionality$)
(defconcept Fenomeno
  :annotations ((DOCUMENTATION "Un evento che avviene senza il coinvolgimento necessario
di un agente intenzionale."))
  :is Phenomenon)

(defconcept Transaction
  :annotations ((DOCUMENTATION "An action with at least two agents and a patient having other
actions as parts. The patient partecipant is exchanged between the agents."))
  :is-primitive |Action|)
(defconcept Transazione-Economica :is Transaction)
(defconcept Cognitive-State
  :is-primitive State)
(defconcept Stato-Cognitivo :is Cognitive-State)
(defconcept Flux
  :annotations ((Plural-P))
  :is-primitive (:and Occurrence
                      (:at-least 2 |Member| Occurrence)))
(defconcept Emotion
  :is-primitive Cognitive-State)

#|
  :implies (:satisfies ?x
            (:and 
             (Occurrence ?x)
             (:exists (?y ?z)
              (:and
               (:not (Singular ?x))
               (Singular ?y)
               (Singular ?z)
               (Occurrence ?y)
               (Occurrence ?z)
               (IDENTITY ?x (MEREO-SUM ?y ?z)))))))
|#
(defconcept Flusso
  :is Flux)


;;;Feature:
(defconcept |Feature|
  :annotations ((Generically-Constantly-Dependent) (Heterogeneous-Unity-Carrier) (Non-Extensional-P)
                ;;; (Singular-P)
                (DOCUMENTATION "Features are 'parasitic entities', that exist insofar their host exists. 
Typical examples of features are holes, bumps, boundaries, or spots of color. Features may be relevant 
parts of their host, like a bump or an edge, or dependent regions like a hole in a piece of cheese, 
the underneath of a table, the front of a house, or the shadow of a tree, which are not parts of their host. 
All features are essential wholes, but no common unity criterion may exist for all of them. However, typical 
features have a topological unity, as they are singular entities."))
  :is-primitive Entity
  :implies (:at-least 1 HOST)
  :in-partition $Entity$)
(defconcept Caratteristica :is |Feature|)
(defconcept Relevant-Part
  :is-primitive |Feature|)
(defconcept Parte-rilevante :is Relevant-Part)
(defconcept Dependent-Place
  :is-primitive |Feature|)
(defconcept Luogo-dipendente :is Dependent-Place)

;;;Abstraction:
(defconcept Abstraction
  :annotations ((Enduring-P) (Always-Present-P) (Independent)
                (DOCUMENTATION "Abstractions are entities that are not concrete, that is, 
they do not have a physical location. Conceptual spaces are the first example of abstractions: 
time, geometric space, length, color are all conceptual spaces, with different topological 
structure. Terms like red, long, old, recent correspond to regions in a conceptual space 
(and therefore to particulars, not universals). We can describe therefore the structure of 
a conceptual space with a first-order theory, using topological notions: for instance, we 
can say that red is adjacent to brown. Depending on the way a conceptual space is partitioned, 
and on the metric (if any) imposed on it, we can have different equivalent ways of describing 
a certain quality. Other abstractions are sets, symbols, propositions, structures."))
  :is-primitive Entity
  :implies (:all HAS-QUALITY Incoherent Spatial-Location)
  :in-partition $Entity$)
(defconcept Astrazione :is Abstraction)

(defconcept |Set|
  :is-primitive Abstraction) 
(defconcept Insieme-matematico :is |Set|)
