
(cc Upper-Level)

;;;;;;;;;;;;;;;;;;;;;;;
;;;Part relations (intracategorial):
;;;;;;;;;;;;;;;;;;;;;;;

(defrelation PART
  :is-primitive CONCEPTUAL-RELATION
  ) ;:antecedents (:compose PART PART))

(defrelation PART-OF
  :is (:inverse PART))

(defrelation PROPER-PART
  :is-primitive CONCEPTUAL-RELATION)

(defrelation PROPER-PART-OF
  :is (:inverse PROPER-PART))

(defrelation ESSENTIAL-PART
  :is-primitive PART)
(defrelation ESSENTIAL-PART-OF
  :is (:inverse ESSENTIAL-PART))

(defrelation SPATIAL-PART
  :is-primitive PART)
(defrelation SPATIAL-PART-OF
  :is (:inverse SPATIAL-PART))

(defrelation COMPONENT
  :is-primitive PART)
(defrelation COMPONENT-OF
  :is (:inverse COMPONENT))

(defrelation |Member|
  :is-primitive COMPONENT)
(defrelation |Member-of|
  :is (inverse |Member|))


;;;;;;;;;;;;;;;;;;;;;;;
;;;Quality relations (intercategorial):
;;;;;;;;;;;;;;;;;;;;;;;

(defrelation INHERES-IN
  :is-primitive CONCEPTUAL-RELATION
  :domain Quality
  :range Entity)
(defrelation HAS-QUALITY
  :is (:inverse INHERES-IN))

(defrelation HOST
  :is-primitive CONCEPTUAL-RELATION
  :domain |Feature|
  :range Entity)
(defrelation HOST-OF
  :is (:inverse HOST))


;;;;;;;;;;;;;;;;;;;;;;;
;;;Representation relations (intercategorial)
;;;;;;;;;;;;;;;;;;;;;;;

(defrelation SIGN-OF
  :is-primitive CONCEPTUAL-RELATION)
(defrelation SIGN :is (:inverse SIGN-OF))

(defrelation REPRESENTS
  :is-primitive SIGN-OF
  :domain Abstract-Object
  :range Entity)
(defrelation REPRESENTED-BY
  :is (:inverse REPRESENTS))

(defrelation INTERNALLY-REPRESENTS
  :is-primitive SIGN-OF
  :domain Cognitive-State
  :range Entity)
(defrelation INTERNALLY-REPRESENTED-BY
  :is (:inverse REPRESENTS))

(defrelation REGULATES
  :is-primitive REPRESENTS)
(defrelation REGULATED-BY
  :is (:inverse REGULATES))

(defrelation METHOD-OF
  :is-primitive REPRESENTS
  :domain |Plan|)
(defrelation METHOD
  :is (:inverse METHOD-OF))


(defrelation SUPPORT-OF
  :is-primitive CONCEPTUAL-RELATION
  :domain Entity
  :range Abstract-Object)
(defrelation SUPPORT
  :is (:inverse SUPPORT-OF))


;;;;;;;;;;;;;;;;;;;;;;;
;;;Event-based temporal relations (intracategorial)
;;;;;;;;;;;;;;;;;;;;;;;

(defrelation TEMPORAL-RELATION
  :is-primitive CONCEPTUAL-RELATION
  :domain Occurrence
  :range Occurrence
  :characteristics :symmetric)

(defrelation PRECEDES
  :is-primitive TEMPORAL-RELATION)
(defrelation FOLLOWS
  :is (:inverse PRECEDES))

(defrelation CO-OCCURS
  :is-primitive TEMPORAL-RELATION
  :characteristics :symmetric)

(defrelation TEMPORAL-CONNECTION
  :is-primitive TEMPORAL-RELATION
  :characteristics :symmetric)

(defrelation TEMPORALLY-CONTAINS
  :is (:and TEMPORAL-RELATION
            (:compose PART CO-OCCURS)))
(defrelation TEMPORALLY-CONTAINED-IN
  :is (:inverse TEMPORALLY-CONTAINS))

(defrelation STARTS
  :is-primitive (:and TEMPORALLY-CONTAINED-IN
                      (:compose PRECEDES PART-OF)))
(defrelation STARTED-BY
  :is (:inverse STARTS))

(defrelation CONCLUDES
  :is-primitive (:and TEMPORALLY-CONTAINED-IN
                      (:compose FOLLOWS PART-OF)))
(defrelation CONCLUDED-BY
  :is (:inverse CONCLUDES))

(defrelation TEMPORAL-INTERSECTION
  :is (:and TEMPORAL-RELATION
            (:compose PART CO-OCCURS PART-OF))
  :characteristics :symmetric)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;Participation (intercategorial):
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defrelation PARTICIPANT
  :is-primitive CONCEPTUAL-RELATION
  :domain Occurrence
  :range Object)  ;;;non serve per ora: (:or Object Aggregate |Feature|))

(defrelation PARTICIPANT-IN
  :is (:inverse PARTICIPANT))

;;;;;;;;;;;;;;;;;;;;
   ;;;initiators:
;;;;;;;;;;;;;;;;;;;;
(defrelation PERFORMS
  :is-primitive PARTICIPANT-IN)
(defrelation PERFORMED-BY
  :is (:inverse PERFORMS))
(defrelation PRESCRIBES
  :is-primitive PERFORMS)
(defrelation PRESCRIBED-BY
  :is (:inverse PRESCRIBES))

(defrelation AGENT-OF
  :is PERFORMS)
(defrelation AGENT
  :is PERFORMED-BY)


;;;;;;;;;;;;;;;;;;;;
   ;;;patients:
;;;;;;;;;;;;;;;;;;;;
(defrelation PATIENT-OF
  :is-primitive PARTICIPANT-IN)
(defrelation PATIENT
  :is (:inverse PATIENT-OF))

(defrelation TARGET-OF
  :is-primitive PATIENT-OF)
(defrelation TARGET
  :is (:inverse TARGET-OF))


;;;;;;;;;;;;;;;;;;;;
   ;;;instruments:
;;;;;;;;;;;;;;;;;;;;
(defrelation USED-IN
  :is-primitive PARTICIPANT-IN)
(defrelation SITUATION-OF-USE-OF
  :is (:inverse USED-IN))

(defrelation INSTRUMENT-OF
  :is-primitive used-IN)
(defrelation INSTRUMENT
  :is (:inverse INSTRUMENT-OF))

(defrelation RESOURCE-FOR
  :is-primitive USED-IN)
(defrelation RESOURCE
  :is (:inverse RESOURCE-FOR))

;;;;;;;;;;;;;;;;;;;;
   ;;;consequences and effects:
;;;;;;;;;;;;;;;;;;;;
(defrelation CONSEQUENCE-OF
  :is-primitive PARTICIPANT-IN)
(defrelation CONSEQUENCE
  :is (:inverse CONSEQUENCE-OF))

(defrelation PRODUCT-OF
  :is-primitive CONSEQUENCE-OF
  :domain Object)
(defrelation PRODUCT
  :is (:inverse PRODUCT-OF))

;;;;;;;;;;;;;;;;;;;;
   ;;;substrates:
;;;;;;;;;;;;;;;;;;;;
(defrelation SUBSTRATE-OF
  :is-primitive PARTICIPANT-IN)
(defrelation SUBSTRATE
  :is (:inverse SUBSTRATE-OF))

(defrelation EXPERIENCES
  :is-primitive SUBSTRATE-OF)

   ;;;relazioni di collegamento con gli stati (provvisorio):
(defrelation HAS-STATE
  :is-primitive SUBSTRATE-OF)
(defrelation STATE-OF
  :is (:inverse HAS-STATE))

;;;;;;;;;;;;;;;;;;;;
   ;;;Composed (?mixing') relations:
;;;;;;;;;;;;;;;;;;;;
(defrelation MIXING-RELATION
  :annotations ((DOCUMENTATION "A relation that composes relations from
different hierarchies. For example, a participation relation
composed with a representation relation."))
  :is-primitive CONCEPTUAL-RELATION
  :domain Entity
  :range Entity
  :characteristics :symmetric)

(defrelation CO-PARTICIPATES-WITH
  :is (:and MIXING-RELATION
            (:compose PARTICIPANT-IN PARTICIPANT))
  :characteristics :symmetric)


(defrelation RESULT-OF
  :is-primitive (:and MIXING-RELATION
                      (:compose PARTICIPANT PARTICIPANT-IN)
                      FOLLOWS))
(defrelation RESULT
  :is (:inverse RESULT-OF))

(defrelation INVOLVED-IN
  :is (:and MIXING-RELATION
            (:compose PARTICIPANT-IN REPRESENTED-BY)))
;;;  :range Information) 
(defrelation INVOLVES
  :is (:inverse INVOLVED-IN))

(defrelation USES
  :is (:and MIXING-RELATION
            (:compose PERFORMS SITUATION-OF-USE-OF)))
(defrelation USED-BY
  :is (:inverse USES))

(defrelation EXPLOITS
  :is (:and MIXING-RELATION
            (:compose METHOD-OF SITUATION-OF-USE-OF)))
(defrelation EXPLOITED-BY
  :is (:inverse EXPLOITS))


;;;;;;;;;;;;;;;;;;;;
;;;Localization within quality spaces
;;;;;;;;;;;;;;;;;;;;

(defrelation HAS-QUALE
  :is-primitive CONCEPTUAL-RELATION
  :domain Quality
  :range Quality-Space)
(defrelation QUALE-OF
  :is (:inverse HAS-QUALE))

(defrelation LOCATION
  :is-primitive HAS-QUALE)
(defrelation LOCATION-OF
  :is (:inverse LOCATION))

;;;;;;;;;;;;;;;;;;;;;;;
;;;Localization within qualities
;;;;;;;;;;;;;;;;;;;;;;;

(defrelation HAS-SPATIAL-LOCATION
  :is (:and HAS-QUALITY
            (:range Spatial-Location)))
(defrelation SPATIAL-LOCATION-OF
  :is (:inverse HAS-SPATIAL-LOCATION))

(defrelation HAS-TEMPORAL-LOCATION
  :is (:and HAS-QUALITY
            (:range Temporal-Location)))
(defrelation TEMPORAL-LOCATION-OF
  :is (:inverse HAS-TEMPORAL-LOCATION))

(defrelation HAS-ABSTRACT-LOCATION
  :is (:and HAS-QUALITY
            (:range Abstract-Location)))
(defrelation TEMPORAL-LOCATION-OF
  :is (:inverse HAS-TEMPORAL-LOCATION))

(defrelation SPATIAL-BOUNDARY
  :is-primitive HAS-SPATIAL-LOCATION)
(defrelation SPATIAL-BOUNDARY-OF
  :is (:inverse SPATIAL-BOUNDARY))

(defrelation HAS-PHYSICAL-LOCATION
  :is (:and MIXING-RELATION
            (:compose HAS-SPATIAL-LOCATION
                      SPATIAL-LOCATION-OF)))
(defrelation PHYSICAL-LOCATION-OF
  :is (:inverse HAS-PHYSICAL-LOCATION))

(defrelation CONNECTED
  :is-primitive CONCEPTUAL-RELATION
  :domain Spatial-Location
  :range Spatial-Location
  :characteristics :symmetric)

;;;;;;;;;;;;;;;;;;;;;;;
;;;Extrinsic (number) relations
;;;;;;;;;;;;;;;;;;;;;;;
;; start 06-08-2002

(defrelation NUMEROSITY
  :is-primitive EXTRINSIC-RELATION
  :range Number)  ;;;currently supported with Loom::Number, out of our domain!

(defrelation NUMEROSITY-OF
  :is (:inverse NUMEROSITY))

(defrelation UNIT
  :is-primitive EXTRINSIC-RELATION
  :domain Thing  ;;;deve valere per beni in generale e per ammontare
  :range Measurement-Unit)
;; end 06-08-2002
(defrelation UNIT-of
  :is (:inverse UNIT))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;Identity
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defrelation IDENTITY-C
  :is-primitive IDENTITY
  :domain Entity
  :range Entity)

(defrelation DIFFERENT-FROM
  :is-primitive CONCEPTUAL-RELATION
;  :implies (:satisfies (?x ?y)
;             (:and (Entity ?x)
;                   (Entity ?y)
;                   (:fail (IDENTITY-C ?x ?y))))
  :domain Entity
  :range Entity
  :characteristic :symmetric)

;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;Institutional relations
;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defrelation OWNS
  :is-primitive CONCEPTUAL-RELATION
  :domain Social-Object)
(defrelation OWNED-BY
  :is (:inverse OWNS))
